@@ -340,10 +340,8 @@ class ReligionManager : IsPartOfGameInfoSerialization {
     fun getBeliefsToChooseAtFounding(): Counter<BeliefType> = getBeliefsToChooseAtProphetUse(false)
     fun getBeliefsToChooseAtEnhancing(): Counter<BeliefType> = getBeliefsToChooseAtProphetUse(true)
 
-    fun chooseBeliefs(beliefs: List<Belief>, iconName: String? = null, religionName: String? = null, useFreeBeliefs: Boolean = false) {
+    fun chooseBeliefs(beliefs: List<Belief>, useFreeBeliefs: Boolean = false) {
         when (religionState) {
-            ReligionState.FoundingReligion ->
-                foundReligion(iconName!!, religionName!!)
             ReligionState.EnhancingReligion -> {
                 religionState = ReligionState.EnhancedReligion
                 for (unique in civInfo.getTriggeredUniques(UniqueType.TriggerUponEnhancingReligion))
@@ -365,6 +363,17 @@ class ReligionManager : IsPartOfGameInfoSerialization {
                 .filter { it.type == BeliefType.Founder || it.type == BeliefType.Enhancer }
                 .map { it.name }
         )
+
+        for (unique in civInfo.getTriggeredUniques(UniqueType.TriggerUponAdoptingPolicyOrBelief))
+            for (belief in beliefs)
+                if (unique.conditionals.any {it.type == UniqueType.TriggerUponAdoptingPolicyOrBelief && it.params[0] == belief.name})
+                    UniqueTriggerActivation.triggerCivwideUnique(unique, civInfo,
+                        triggerNotificationText = "due to adopting [${belief.name}]")
+
+        for (belief in beliefs)
+            for (unique in belief.uniqueObjects)
+                UniqueTriggerActivation.triggerCivwideUnique(unique, civInfo)
+
         // decrement free beliefs if used
         if (useFreeBeliefs && hasFreeBeliefs()) {
             for (belief in beliefs) {
@@ -381,7 +390,7 @@ class ReligionManager : IsPartOfGameInfoSerialization {
     }
 
 
-    private fun foundReligion(displayName: String, name: String) {
+    internal fun foundReligion(displayName: String, name: String) {
         val newReligion = Religion(name, civInfo.gameInfo, civInfo.civName)
         newReligion.displayName = displayName
         if (religion != null) {
