@@ -8,13 +8,18 @@ import com.badlogic.gdx.utils.SerializationException
 import com.unciv.UncivGame
 import com.unciv.json.fromJsonFile
 import com.unciv.json.json
-import com.unciv.logic.*
+import com.unciv.logic.CompatibilityVersion
+import com.unciv.logic.GameInfo
+import com.unciv.logic.GameInfoPreview
+import com.unciv.logic.GameInfoSerializationVersion
+import com.unciv.logic.HasGameInfoSerializationVersion
+import com.unciv.logic.UncivShowableException
 import com.unciv.models.metadata.GameSettings
 import com.unciv.models.metadata.doMigrations
 import com.unciv.models.metadata.isMigrationNecessary
 import com.unciv.ui.screens.savescreens.Gzip
 import com.unciv.utils.Log
-import com.unciv.utils.concurrency.Concurrency
+import com.unciv.utils.Concurrency
 import com.unciv.utils.debug
 import kotlinx.coroutines.Job
 import java.io.File
@@ -140,8 +145,8 @@ class UncivFiles(
     //endregion
     //region Saving
 
-    fun saveGame(game: GameInfo, GameName: String, saveCompletionCallback: (Exception?) -> Unit = { if (it != null) throw it }): FileHandle {
-        val file = getSave(GameName)
+    fun saveGame(game: GameInfo, gameName: String, saveCompletionCallback: (Exception?) -> Unit = { if (it != null) throw it }): FileHandle {
+        val file = getSave(gameName)
         saveGame(game, file, saveCompletionCallback)
         return file
     }
@@ -333,7 +338,7 @@ class UncivFiles(
         fun gameInfoFromString(gameData: String): GameInfo {
             val unzippedJson = try {
                 Gzip.unzip(gameData.trim())
-            } catch (ex: Exception) {
+            } catch (_: Exception) {
                 gameData.trim()
             }
             val gameInfo = try {
@@ -348,7 +353,6 @@ class UncivFiles(
                 // this means there wasn't an immediate error while serializing, but this version will cause other errors later down the line
                 throw IncompatibleGameInfoVersionException(gameInfo.version)
             }
-            gameInfo.version = GameInfo.CURRENT_COMPATIBILITY_VERSION
             gameInfo.setTransients()
             return gameInfo
         }
@@ -363,6 +367,7 @@ class UncivFiles(
 
         /** Returns gzipped serialization of [game], optionally gzipped ([forceZip] overrides [saveZipped]) */
         fun gameInfoToString(game: GameInfo, forceZip: Boolean? = null): String {
+            game.version = GameInfo.CURRENT_COMPATIBILITY_VERSION
             val plainJson = json().toJson(game)
             return if (forceZip ?: saveZipped) Gzip.zip(plainJson) else plainJson
         }
@@ -402,6 +407,7 @@ class UncivFiles(
         try {
             saveGame(gameInfo, AUTOSAVE_FILE_NAME)
         } catch (oom: OutOfMemoryError) {
+            Log.error("Ran out of memory during autosave", oom)
             return  // not much we can do here
         }
 
@@ -427,14 +433,14 @@ class UncivFiles(
     }
 
     fun loadLatestAutosave(): GameInfo {
-        try {
-            return loadGameByName(AUTOSAVE_FILE_NAME)
-        } catch (ex: Exception) {
+        return try {
+            loadGameByName(AUTOSAVE_FILE_NAME)
+        } catch (_: Exception) {
             // silent fail if we can't read the autosave for any reason - try to load the last autosave by turn number first
             val autosaves = getSaves().filter { it.name() != AUTOSAVE_FILE_NAME && it.name().startsWith(
                 AUTOSAVE_FILE_NAME
             ) }
-            return loadGameFromFile(autosaves.maxByOrNull { it.lastModified() }!!)
+            loadGameFromFile(autosaves.maxByOrNull { it.lastModified() }!!)
         }
     }
 
