@@ -27,7 +27,6 @@ import com.unciv.ui.components.extensions.isNarrowerThan4to3
 import com.unciv.ui.images.ImageGetter
 import com.unciv.ui.popups.activePopup
 import com.unciv.ui.popups.options.OptionsPopup
-import com.unciv.ui.tutorials.TutorialController
 
 abstract class BaseScreen : Screen {
 
@@ -97,7 +96,14 @@ abstract class BaseScreen : Screen {
 
     override fun hide() {}
 
+    /**
+     * Called when this screen should release all resources.
+     *
+     * This is _not_ called automatically by Gdx, but by the [screenStack][UncivGame.screenStack]
+     * functions in [UncivGame], e.g. [replaceCurrentScreen][UncivGame.replaceCurrentScreen].
+     */
     override fun dispose() {
+        // FYI - This is a method of Gdx [Screen], not of Gdx [Disposable], but the one below _is_.
         stage.dispose()
     }
 
