@@ -5,10 +5,11 @@ import com.badlogic.gdx.graphics.Color
 import com.badlogic.gdx.scenes.scene2d.ui.Image
 import com.badlogic.gdx.scenes.scene2d.ui.Table
 import com.badlogic.gdx.utils.Align
+import com.unciv.GUI
 import com.unciv.UncivGame
 import com.unciv.logic.automation.Automation
 import com.unciv.logic.city.City
-import com.unciv.logic.city.IConstruction
+import com.unciv.models.ruleset.IConstruction
 import com.unciv.logic.map.tile.Tile
 import com.unciv.models.TutorialTrigger
 import com.unciv.models.UncivSound
@@ -53,20 +54,20 @@ class CityScreen(
     }
 
     /** Toggles or adds/removes all state changing buttons */
-    val canChangeState = UncivGame.Current.worldScreen!!.canChangeState
+    val canChangeState = GUI.isAllowedChangeState()
 
     // Clockwise from the top-left
 
     /** Displays current production, production queue and available productions list
-     *  Not a widget, but manages two: construction queue, info toggle button, buy buttons
-     *  in a Table holder on upper LEFT, and available constructions in a ScrollPane lower LEFT.
+     *  Not a widget, but manages two: construction queue + buy buttons
+     *  in a Table holder on TOP LEFT, and available constructions in a ScrollPane BOTTOM LEFT.
      */
     private var constructionsTable = CityConstructionsTable(this)
 
     /** Displays raze city button - sits on TOP CENTER */
     private var razeCityButtonHolder = Table()
 
-    /** Displays city stats info */
+    /** Displays city stats, population management, religion, built buildings info - TOP RIGHT */
     private var cityStatsTable = CityStatsTable(this)
 
     /** Displays tile info, alternate with selectedConstructionTable - sits on BOTTOM RIGHT */
@@ -258,7 +259,8 @@ class CityScreen(
             addWltkIcon("OtherIcons/WLTK 1") { color = Color.FIREBRICK }.padRight(10f)
         }
 
-        if (city.isPuppet) {
+        val canAnnex = !city.civ.hasUnique(UniqueType.MayNotAnnexCities)
+        if (city.isPuppet && canAnnex) {
             val annexCityButton = "Annex city".toTextButton()
             annexCityButton.labelCell.pad(10f)
             annexCityButton.onClick {
@@ -271,8 +273,9 @@ class CityScreen(
             val razeCityButton = "Raze city".toTextButton()
             razeCityButton.labelCell.pad(10f)
             razeCityButton.onClick { city.isBeingRazed = true; update() }
-            if (!canChangeState || !city.canBeDestroyed())
+            if (!canChangeState || !city.canBeDestroyed() || !canAnnex) {
                 razeCityButton.disable()
+            }
 
             razeCityButtonHolder.add(razeCityButton) //.colspan(cityPickerTable.columns)
         } else {
