@@ -13,14 +13,13 @@ import com.unciv.models.ruleset.Ruleset
 import com.unciv.models.translations.tr
 import com.unciv.ui.screens.civilopediascreen.FormattedLine
 import com.unciv.ui.images.ImageGetter
-import com.unciv.ui.screens.mapeditorscreen.IMapEditorEditSubTabs
-import com.unciv.ui.screens.mapeditorscreen.MapEditorEditFeaturesTab
-import com.unciv.ui.screens.mapeditorscreen.MapEditorEditImprovementsTab
-import com.unciv.ui.screens.mapeditorscreen.MapEditorEditResourcesTab
-import com.unciv.ui.screens.mapeditorscreen.MapEditorEditRiversTab
-import com.unciv.ui.screens.mapeditorscreen.MapEditorEditStartsTab
-import com.unciv.ui.screens.mapeditorscreen.MapEditorEditTerrainTab
-import com.unciv.ui.screens.mapeditorscreen.MapEditorEditWondersTab
+import com.unciv.ui.screens.mapeditorscreen.tabs.MapEditorEditFeaturesTab
+import com.unciv.ui.screens.mapeditorscreen.tabs.MapEditorEditImprovementsTab
+import com.unciv.ui.screens.mapeditorscreen.tabs.MapEditorEditResourcesTab
+import com.unciv.ui.screens.mapeditorscreen.tabs.MapEditorEditRiversTab
+import com.unciv.ui.screens.mapeditorscreen.tabs.MapEditorEditStartsTab
+import com.unciv.ui.screens.mapeditorscreen.tabs.MapEditorEditTerrainTab
+import com.unciv.ui.screens.mapeditorscreen.tabs.MapEditorEditWondersTab
 import com.unciv.ui.screens.mapeditorscreen.MapEditorScreen
 import com.unciv.ui.screens.mapeditorscreen.TileInfoNormalizer
 import com.unciv.ui.screens.mapeditorscreen.tabs.MapEditorOptionsTab.TileMatchFuzziness
@@ -90,7 +89,11 @@ class MapEditorEditTab(
             defaults().pad(10f).left()
             add(brushLabel)
             brushCell = add().padLeft(0f)
-            brushSlider = UncivSlider(1f,6f,1f, initial = 1f, getTipText = { getBrushTip(it).tr() }, permanentTip = false) {
+            brushSlider = UncivSlider(1f,6f,1f,
+                initial = 1f,
+                getTipText = { getBrushTip(it).tr() },
+                tipType = UncivSlider.TipType.Auto
+            ) {
                 brushSize = if (it > 5f) -1 else it.toInt()
                 brushLabel.setText("Brush ([${getBrushTip(it, true)}]):".tr())
             }
@@ -189,6 +192,7 @@ class MapEditorEditTab(
 
     fun tileClickHandler(tile: Tile) {
         if (brushSize < -1 || brushSize > 5 || brushHandlerType == BrushHandlerType.None) return
+        if (editorScreen.mapHolder.isPanning || editorScreen.mapHolder.isZooming()) return
         editorScreen.hideSelection()
 
         when (brushHandlerType) {
